ConnectionFailed class

A connection attempt failed.

Inheritance

Constructors

ConnectionFailed({required Object error, required int attemptNumber, required bool willRetry})
Creates a ConnectionFailed event.

Properties

attemptNumber int
Which attempt number failed (1-based).
final
error Object
The error that caused the failure.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
When this event occurred.
finalinherited
willRetry bool
Whether the manager will retry this connection.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited